@@ -4,7 +4,7 @@ import json
 import socket
 import time
 
-print('默认启动edge浏览器')
+print('默认启动edge浏览器,by:lixin, 951163006@qq.com')
 
 
 class WebBot:
